%CODIFICADOR DE LOS TÉRMINOS LTP.
%function[Nc,bc]=ltpcod(N,b)
%Entradas:
%N:término de autocorrelación.
%b:ganancia de autocorrelación.
%Salidas:
%Nc:término de autocorrelación codificado.
%bc:ganancia de autocorrelación codificada.
function[Nc,bc]=ltpcod(N,b)
Nc=N;
DLB=[0.2 0.5 0.8];
if(b<=DLB(1))
bc=0;
elseif(b<=DLB(2))
bc=1;
elseif(b<=DLB(3))
bc=2;
else
bc=3;
end


